// Licensed under the Apache License, Version 2.0 (the "License"); you may not
// use this file except in compliance with the License. You may obtain a copy of
// the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
// WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
// License for the specific language governing permissions and limitations under
// the License.

import React from "react";
import FauxtonAPI from "../../core/api";
import DocumentationComponents from "./components";
import { OnePaneSimpleLayout } from '../components/layouts';

var DocumentationRouteObject = FauxtonAPI.RouteObject.extend({
  selectedHeader: "Documentation",
  hideApiBar: true,
  hideNotificationCenter: true,
  routes: {
    documentation: "documentation",
  },
  roles: ["fx_loggedIn"],
  documentation: () => {
    return <OnePaneSimpleLayout
      component={<DocumentationComponents.DocumentationPage/>}
      docURL=""
      endpoint=""
      crumbs={[
        {'name': 'Documentation'}
      ]}
    />;
  },
});
DocumentationRouteObject.RouteObjects = [DocumentationRouteObject];

export default DocumentationRouteObject;
